==> CGAL-6.1-doc_html.tar.xz: doc_html/Arrangement_on_surface_2/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "CGAL 6.1 - 2D Arrangements", "index.html", [
    [ "User Manual", "index.html", "index" ],
    [ "Reference Manual", "modules.html", "modules" ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Bibliography", "citelist.html", null ],
    [ "Class and Concept List", "annotated.html", "annotated" ],
    [ "Examples", "examples.html", "examples" ]
  ] ]
];

var NAVTREEINDEX =
[
"Arrangement_on_surface_2_2Bezier_curves_8cpp-example.html",
"classAosDcelIsolatedVertex.html#aae9a2f235cd1299ff3d7e32fb9ab8d05",
"classAosTraits_1_1IsVertical__2.html",
"classCGAL_1_1Arr__bounded__planar__topology__traits__2.html#ad9e26e2c2fb67e0d8a4ba9ac1849c2e4",
"classCGAL_1_1Arr__face__index__map.html#aca9b0c1a03ab484c85cdbea9382a4488",
"classCGAL_1_1Arr__rational__function__traits__2_1_1Curve__2.html#a635a7d11463a202fa00533f32d2aecae",
"classCGAL_1_1Arrangement__on__surface__2.html#a43113edb82930474c25b57b9a8e2143f",
"group__PkgArrangementOnSurface2Insert.html#ga92e366673e866d93370d61a828f8e5e2"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> CGAL-6.1.1-doc_html.tar.xz: doc_html/Arrangement_on_surface_2/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "CGAL 6.1.1 - 2D Arrangements", "index.html", [
    [ "User Manual", "index.html", "index" ],
    [ "Reference Manual", "modules.html", "modules" ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Bibliography", "citelist.html", null ],
    [ "Class and Concept List", "annotated.html", "annotated" ],
    [ "Examples", "examples.html", "examples" ]
  ] ]
];

var NAVTREEINDEX =
[
"Arrangement_on_surface_2_2Bezier_curves_8cpp-example.html",
"classAosDcelIsolatedVertex.html#aae9a2f235cd1299ff3d7e32fb9ab8d05",
"classAosTraits_1_1IsVertical__2.html",
"classCGAL_1_1Arr__bounded__planar__topology__traits__2.html#ad9e26e2c2fb67e0d8a4ba9ac1849c2e4",
"classCGAL_1_1Arr__face__index__map.html#aca9b0c1a03ab484c85cdbea9382a4488",
"classCGAL_1_1Arr__rational__function__traits__2_1_1Curve__2.html#a635a7d11463a202fa00533f32d2aecae",
"classCGAL_1_1Arrangement__on__surface__2.html#a43113edb82930474c25b57b9a8e2143f",
"group__PkgArrangementOnSurface2Insert.html#ga92e366673e866d93370d61a828f8e5e2"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
